@@ -154,6 +154,11 @@ QString unhtmlize(QString str, bool b_ascii) {
 HistoryView::HistoryView(QWidget *parent) : QTextEdit(parent), i_pos(0) {
 	i_pos = 0;
 	last_ans = 0;
+#ifdef _WIN32
+	has_lock_symbol = 1;
+#else
+	has_lock_symbol = -1;
+#endif
 	setReadOnly(true);
 	QImage img1px(1, 1, QImage::Format_ARGB32);
 	img1px.fill(Qt::transparent);
@@ -300,14 +305,6 @@ void remove_top_border(QString &s_text) {
 	}
 }
 
-QString get_uah(QWidget *w) {
-	if((settings->first_time || settings->preferences_version[0] < 4 || (settings->preferences_version[0] == 4 && settings->preferences_version[1] == 0)) && settings->history_answer.empty() && QDate::currentDate().year() == 2022 && QDate::currentDate().month() < 8) {
-		QFontMetrics fm(w->font());
-		return QString("<tr><td colspan=\"2\" style=\"text-align:center; padding-top: 6px; padding-bottom: 12px\"><a href=\"https://en.wikipedia.org/wiki/War_crimes_in_the_2022_Russian_invasion_of_Ukraine\"><img src=\":/data/flags/UAH.png\" height=\"%1\"></a></td>").arg(fm.ascent() * 1.5);
-	}
-	return QString();
-}
-
 void HistoryView::loadInitial() {
 	s_text.clear();
 	i_pos = 0;
@@ -332,8 +329,7 @@ void HistoryView::loadInitial() {
 		}
 	}
 
-	QString uah_str = get_uah(this);
-	if(!s_text.isEmpty() || !uah_str.isEmpty()) {
+	if(!s_text.isEmpty()) {
 		if((settings->color == 2 && (s_text.contains("color:#00") || s_text.contains("color:#58"))) || (settings->color != 2 && (s_text.contains("color:#FF") || s_text.contains("color:#AA")))) {
 			replaceColors(s_text);
 			for(size_t i = 0; i < settings->v_expression.size(); i++) {
@@ -343,7 +339,7 @@ void HistoryView::loadInitial() {
 				}
 			}
 		}
-		setHtml("<body color=\"" + textColor().name() + "\"><table width=\"100%\">" + uah_str + s_text + "</table></body>");
+		setHtml("<body color=\"" + textColor().name() + "\"><table width=\"100%\">" + s_text + "</table></body>");
 	}
 }
 
@@ -353,6 +349,41 @@ void HistoryView::loadInitial() {
 
 void HistoryView::addResult(std::vector<std::string> values, std::string expression, bool pexact, std::string parse, int exact, bool dual_approx, const QString &image, bool *implicit_warning, bool initial_load, size_t index) {
 	if(initial_load && settings->v_delexpression[index]) return;
+	QString serror;
+	bool b_parse_error = false;
+	if(!initial_load && CALCULATOR->message()) {
+		do {
+			if(CALCULATOR->message()->category() == MESSAGE_CATEGORY_IMPLICIT_MULTIPLICATION && (settings->implicit_question_asked || implicit_warning)) {
+				if(!settings->implicit_question_asked) *implicit_warning = true;
+			} else {
+				MessageType mtype = CALCULATOR->message()->type();
+				serror += "<tr><td class=\"message\" colspan=\"2\" style=\"text-align:left; font-size:normal";
+				if(mtype == MESSAGE_ERROR || mtype == MESSAGE_WARNING) {
+					serror += "; color: ";
+					if(mtype == MESSAGE_ERROR) {
+						if(settings->color == 2) serror += "#FFAAAA";
+						else serror += "#800000";
+					} else {
+						if(settings->color == 2) serror += "#AAAAFF";
+						else serror += "#000080";
+					}
+					serror += "";
+					if(CALCULATOR->message()->stage() == MESSAGE_STAGE_PARSING) b_parse_error = true;
+				}
+				serror += "\">";
+				QString mstr = QString::fromStdString(CALCULATOR->message()->message());
+				if(!mstr.startsWith("-")) serror += "- ";
+				if(settings->printops.use_unicode_signs) {
+					mstr.replace(">=", SIGN_GREATER_OR_EQUAL);
+					mstr.replace("<=", SIGN_LESS_OR_EQUAL);
+					mstr.replace("!=", SIGN_NOT_EQUAL);
+				}
+				serror += mstr.toHtmlEscaped();
+				serror += "</td></tr>";
+			}
+		} while(CALCULATOR->nextMessage());
+		if(serror.isEmpty() && values.empty() && expression.empty() && parse.empty()) return;
+	}
 	PASTE_H
 	QString str;
 	if(!expression.empty() || !parse.empty()) {
@@ -377,8 +408,27 @@ void HistoryView::addResult(std::vector<std::string> values, std::string express
 			}
 		} else {
 			str += QString("<a name=\"%1\" style=\"text-decoration: none\">").arg(initial_load ? (int) index : settings->v_expression.size());
+			if(!pexact) str += SIGN_ALMOST_EQUAL " ";
 			str += QString::fromStdString(parse);
 			str += "</a>";
+			if(b_parse_error && !expression.empty()) {
+				str += "&nbsp;&nbsp;&nbsp; ";
+				if(settings->color == 2) str += "<i style=\"color: #AAAAAA\">";
+				else str += "<i style=\"color: #666666\">";
+				str += QString("<a name=\"e%1\" style=\"text-decoration: none\">").arg(initial_load ? (int) index : settings->v_expression.size());
+				str += QString::fromStdString(replace_parse_colors(expression));
+				str += "</a>";
+				str += "</i>";
+			}
+		}
+		if(initial_load && settings->v_protected[index]) {
+			if(has_lock_symbol < 0) {
+				QFontDatabase database;
+				if(database.families(QFontDatabase::Symbol).contains("Noto Color Emoji")) has_lock_symbol = 1;
+				else has_lock_symbol = 0;
+			}
+			if(has_lock_symbol) str += " <small><sup>🔒</sup></small>";
+			else str += " <small><sup>[P]</sup></small>";
 		}
 		str += "</td></tr>";
 		if(!initial_load) {
@@ -405,38 +455,7 @@ void HistoryView::addResult(std::vector<std::string> values, std::string express
 			settings->v_value[settings->v_value.size() - 1].insert(settings->v_value[settings->v_value.size() - 1].begin(), dual_approx && i == 1 ? settings->history_answer.size() - 1 : settings->history_answer.size());
 		}
 	}
-	if(!initial_load && CALCULATOR->message()) {
-		do {
-			if(CALCULATOR->message()->category() == MESSAGE_CATEGORY_IMPLICIT_MULTIPLICATION && (settings->implicit_question_asked || implicit_warning)) {
-				if(!settings->implicit_question_asked) *implicit_warning = true;
-			} else {
-				MessageType mtype = CALCULATOR->message()->type();
-				str += "<tr><td class=\"message\" colspan=\"2\" style=\"text-align:left; font-size:normal";
-				if(mtype == MESSAGE_ERROR || mtype == MESSAGE_WARNING) {
-					str += "; color: ";
-					if(mtype == MESSAGE_ERROR) {
-						if(settings->color == 2) str += "#FFAAAA";
-						else str += "#800000";
-					} else {
-						if(settings->color == 2) str += "#AAAAFF";
-						else str += "#000080";
-					}
-					str += "";
-				}
-				str += "\">";
-				QString mstr = QString::fromStdString(CALCULATOR->message()->message());
-				if(!mstr.startsWith("-")) str += "- ";
-				if(settings->printops.use_unicode_signs) {
-					mstr.replace(">=", SIGN_GREATER_OR_EQUAL);
-					mstr.replace("<=", SIGN_LESS_OR_EQUAL);
-					mstr.replace("!=", SIGN_NOT_EQUAL);
-				}
-				str += mstr.toHtmlEscaped();
-				str += "</td></tr>";
-			}
-		} while(CALCULATOR->nextMessage());
-		if(str.isEmpty() && values.empty() && expression.empty() && parse.empty()) return;
-	}
+	str += serror;
 	str.replace("</i>", "<img src=\"data://img1px.png\" width=\"1\"/></i>");
 	if(!expression.empty() || !parse.empty()) i_pos = str.length();
 	size_t i_answer_pre = 0;
@@ -546,10 +565,9 @@ void HistoryView::changeEvent(QEvent *e) {
 			}
 		}
 
-		QString uah_str = get_uah(this);
-		if(!s_text.isEmpty() || !uah_str.isEmpty()) {
+		if(!s_text.isEmpty()) {
 			replaceColors(s_text);
-			setHtml("<body color=\"" + textColor().name() + "\"><table width=\"100%\">" + uah_str + s_text + "</table></body>");
+			setHtml("<body color=\"" + textColor().name() + "\"><table width=\"100%\">" + s_text + "</table></body>");
 		}
 		prev_color = textColor();
 	}
@@ -561,14 +579,8 @@ void HistoryView::addMessages() {
 }
 void HistoryView::mouseMoveEvent(QMouseEvent *e) {
 	QString str = anchorAt(e->pos());
-	if(str.isEmpty()) {
-		viewport()->setCursor(Qt::IBeamCursor);
-	} else {
-		viewport()->setCursor(Qt::PointingHandCursor);
-		if(str == "https://en.wikipedia.org/wiki/War_crimes_in_the_2022_Russian_invasion_of_Ukraine") {
-			QToolTip::showText(mapToGlobal(e->pos()), "Please inform yourself about the war crimes\ncommitted against the Ukrainian people.", this);
-		}
-	}
+	if(str.isEmpty()) viewport()->setCursor(Qt::IBeamCursor);
+	else viewport()->setCursor(Qt::PointingHandCursor);
 	QTextEdit::mouseMoveEvent(e);
 }
 void HistoryView::mouseDoubleClickEvent(QMouseEvent *e) {
@@ -798,6 +810,32 @@ void HistoryView::editProtect() {
 	indexAtPos(context_pos, &i1, &i2);
 	if(i1 < 0 || i1 >= (int) settings->v_protected.size()) return;
 	settings->v_protected[i1] = protectAction->isChecked();
+	QString sref = QString::number(i1);
+	int index = s_text.indexOf("<a name=\"" + sref + "\"");
+	if(index < 0) {
+		sref = "e" + QString::number(i1);
+		index = s_text.indexOf("<a name=\"" + sref + "\"");
+	}
+	if(index > 0) {
+		int index2 = s_text.indexOf("</td>", index);
+		if(index2 > 0) {
+			if(protectAction->isChecked()) {
+				if(has_lock_symbol < 0) {
+					QFontDatabase database;
+					if(database.families(QFontDatabase::Symbol).contains("Noto Color Emoji")) has_lock_symbol = 1;
+					else has_lock_symbol = 0;
+				}
+				if(has_lock_symbol) s_text.insert(index2, " <small><sup>🔒</sup></small>");
+				else s_text.insert(index2, " <small><sup>[P]</sup></small>");
+			} else {
+				index = s_text.indexOf(has_lock_symbol ? " <small><sup>🔒</sup></small>" : " <small><sup>[P]</sup></small>", index);
+				if(index > 0) {
+					s_text.remove(index, index2 - index);
+				}
+			}
+		}
+	}
+	setHtml("<body color=\"" + textColor().name() + "\"><table width=\"100%\">" + s_text + "</table></body>");
 }
 void HistoryView::indexAtPos(const QPoint &pos, int *expression_index, int *result_index, int *value_index, QString *anchorstr) {
 	*expression_index = -1;
